/* Beispiele aus dem Buch "LDAP fuer Java-Entwickler", 
 * Stefan Zoerner, 4. aktualisierte Auflage 2013
 *  
 * Webseite zum Buch: http://www.ldapjava.de/ 
 * Software & Support Media GmbH / entwickler.press, http://www.entwickler-press.de/
 */
package ldapbuch.kapitel4.controls;

import javax.naming.Binding;
import javax.naming.NamingEnumeration;
import javax.naming.NamingException;
import javax.naming.OperationNotSupportedException;
import javax.naming.ldap.Control;
import javax.naming.ldap.InitialLdapContext;
import javax.naming.ldap.LdapContext;

/**
 * Portables L&ouml;schen.
 * 
 * L&ouml;schen eines Teilbaumes mit dem Tree Delete Control, oder durch eine
 * rekursive Methode, falls das Control nicht unterstuetzt wird.
 * Verbindungsdaten werden von aussen erwartet (jndi.properties), insbesondere
 * die Authentifizierung wegen des schreibenden Zugriffs.
 * 
 * @author Stefan Z&ouml;rner
 */
public class PortablesLoeschen {

  public static void main(String[] args) throws NamingException {

    LdapContext ctx = new InitialLdapContext();

    LdapContext entry = (LdapContext) ctx.lookup("ou=teilbaum");
    entry.setRequestControls(new Control[] { new TreeDeleteControl() });
    try {
      entry.unbind("");
      System.out
          .println("Eintrag " + entry.getNameInNamespace() + " geloescht");
    } catch (OperationNotSupportedException e) {
      entry.setRequestControls(new Control[0]);
      loescheRekursiv(entry);
    }
  }

  /**
   * L&ouml;scht einen Eintrag, und zuvor rekursiv seine Kinder.
   * 
   * @param ctx
   *          der zu l&ouml;schende Eintrag
   */
  public static void loescheRekursiv(LdapContext ctx) throws NamingException {
    NamingEnumeration<Binding> enumeration = ctx.listBindings("");
    while (enumeration.hasMore()) {
      Binding b = enumeration.next();
      if (b.getObject() instanceof LdapContext) {
        loescheRekursiv((LdapContext) b.getObject());
      }
    }
    ctx.unbind("");
    System.out.println("Eintrag " + ctx.getNameInNamespace() + " geloescht");
  }

}