/* Beispiele aus dem Buch "LDAP fuer Java-Entwickler", 
 * Stefan Zoerner, 4. aktualisierte Auflage 2013
 *  
 * Webseite zum Buch: http://www.ldapjava.de/ 
 * Software & Support Media GmbH / entwickler.press, http://www.entwickler-press.de/
 */
package ldapbuch.kapitel4.controls;

import javax.naming.NamingEnumeration;
import javax.naming.directory.SearchControls;
import javax.naming.directory.SearchResult;
import javax.naming.ldap.Control;
import javax.naming.ldap.InitialLdapContext;
import javax.naming.ldap.LdapContext;
import javax.naming.ldap.SortControl;
import javax.naming.ldap.SortKey;

/**
 * Verwendung eines Controls von Sun -- (Listing 4_31).
 * 
 * Verbindungsdaten werden von aussen erwartet (jndi.properties). Das Beispiel
 * bentigt wegen der Control-Klassen Java 5.
 * 
 * @author Stefan Z&ouml;rner
 */
public class SortControlVerwenden {

  /**
   * Einstiegspunkt.
   * 
   * @param args
   *          Kommandozeilenargumente (keine)
   */
  public static void main(String[] args) throws Exception {

    LdapContext ctx = new InitialLdapContext();

    SortKey key = new SortKey("sn");
    Control control = new SortControl(new SortKey[] { key },
        Control.NONCRITICAL);
    Control[] controls = { control };
    ctx.setRequestControls(controls);

    String base = "dc=bundestag,dc=de";
    String filter = "(&(objectclass=person)(givenname=Petra))";
    SearchControls ctls = new SearchControls();
    ctls.setSearchScope(SearchControls.SUBTREE_SCOPE);

    NamingEnumeration<SearchResult> e = ctx.search(base, filter, ctls);
    while (e.hasMore()) {
      SearchResult result = e.next();
      System.out.println(result.getAttributes().get("cn"));
    }
  }
}
