/* Beispiele aus dem Buch "LDAP fuer Java-Entwickler", 
 * Stefan Zoerner, 4. aktualisierte Auflage 2013
 *  
 * Webseite zum Buch: http://www.ldapjava.de/ 
 * Software & Support Media GmbH / entwickler.press, http://www.entwickler-press.de/
 */
package ldapbuch.kapitel4.ops.del;

import javax.naming.NamingException;
import javax.naming.directory.Attributes;
import javax.naming.directory.BasicAttribute;
import javax.naming.directory.BasicAttributes;
import javax.naming.directory.DirContext;
import javax.naming.directory.InitialDirContext;

/**
 * Programm zum Erzeugen des Teilbaumes aus Abbildung 4_3. Verbindungsdaten
 * (Host, Base DN, Authentifizierung) werden von aussen erwartet
 * (jndi.properties).
 * 
 * @author Stefan Z&ouml;rner
 */
public class TeilbaumBauen {

  /**
   * Einstiegspunkt.
   * 
   * @param args
   *          Kommandozeilenparameter, es werden keine ben&ouml;tigt
   */
  public static void main(String[] args) throws NamingException {

    DirContext ctx = new InitialDirContext();

    // Eintrag anlegen
    DirContext teilbaum = ctx.createSubcontext("ou=teilbaum",
        getUnit("teilbaum"));

    for (int i = 0; i < 5; ++i) {
      String ou = "dummy" + i;
      DirContext dc = teilbaum.createSubcontext("ou=" + ou, getUnit(ou));
      if (i % 3 == 1) {
        dc.createSubcontext("ou=sub", getUnit("sub"));
      }
    }

  }

  public static Attributes getUnit(String ou) {
    // Attribute des Eintrags
    Attributes attrs = new BasicAttributes();
    BasicAttribute ocls = new BasicAttribute("objectClass");
    ocls.add("top");
    ocls.add("organizationalUnit");
    attrs.put(ocls);
    attrs.put("ou", ou);

    return attrs;
  }

}
