/* Beispiele aus dem Buch "LDAP fuer Java-Entwickler", 
 * Stefan Zoerner, 4. aktualisierte Auflage 2013
 *  
 * Webseite zum Buch: http://www.ldapjava.de/ 
 * Software & Support Media GmbH / entwickler.press, http://www.entwickler-press.de/
 */
package ldapbuch.kapitel4.ops.del;

import javax.naming.Binding;
import javax.naming.NamingEnumeration;
import javax.naming.NamingException;
import javax.naming.directory.DirContext;
import javax.naming.directory.InitialDirContext;

/**
 * Rekursive Methode zum Entfernen -- (Listing 4_11).
 * 
 * Verbindungsdaten (Host, Base DN, Authentifizierung) werden von aussen
 * erwartet (jndi.properties).
 * 
 * @author Stefan Z&ouml;rner
 */
public class TeilbaumLoeschen {

  /**
   * Einstiegspunkt.
   * 
   * @param args
   *          Kommandozeilenparameter, es werden keine ben&ouml;tigt
   */
  public static void main(String[] args) throws NamingException {

    DirContext ctx = new InitialDirContext();
    DirContext teilbaum = (DirContext) ctx.lookup("ou=teilbaum");
    loescheRekursiv(teilbaum);
  }

  /**
   * L&ouml;scht einen Eintrag, und zuvor rekursiv seine Kinder.
   * 
   * @param ctx
   *          der zu l&ouml;schende Eintrag
   */
  public static void loescheRekursiv(DirContext ctx) throws NamingException {
    NamingEnumeration<Binding> enm = ctx.listBindings("");
    while (enm.hasMore()) {
      Object obj = enm.next().getObject();
      if (obj instanceof DirContext) {
        loescheRekursiv((DirContext) obj);
      }
    }
    System.out.println("Loesche " + ctx.getNameInNamespace());
    ctx.unbind("");
  }
}
