/* Beispiele aus dem Buch "LDAP fuer Java-Entwickler", 
 * Stefan Zoerner, 4. aktualisierte Auflage 2013
 *  
 * Webseite zum Buch: http://www.ldapjava.de/ 
 * Software & Support Media GmbH / entwickler.press, http://www.entwickler-press.de/
 */
package ldapbuch.kapitel4.ops.modify;

import javax.naming.NamingException;
import javax.naming.directory.Attribute;
import javax.naming.directory.BasicAttribute;
import javax.naming.directory.BasicAttributes;
import javax.naming.directory.DirContext;
import javax.naming.directory.InitialDirContext;
import javax.naming.directory.ModificationItem;

/**
 * &Auml;ndern eines Eintrages -- (Listing 4_12).
 * 
 * Verbindungsdaten (Host, Base DN, Authentifizierung) werden von aussen
 * erwartet (jndi.properties).
 * 
 * @author Stefan Z&ouml;rner
 */
public class EintragVeraendern {

  /**
   * Einstiegspunkt.
   * 
   * @param args
   *          Kommandozeilenparameter, es werden keine ben&ouml;tigt
   */
  public static void main(String[] args) throws NamingException {

    DirContext ctx = new InitialDirContext();

    // Werte fuer Telefonnummer ergaenzen
    Attribute newTels = new BasicAttribute("telephoneNumber");
    newTels.add("0171/642462");
    newTels.add("030/3276452");
    ModificationItem addTel = new ModificationItem(
        DirContext.ADD_ATTRIBUTE, newTels);

    // Attributwert fuer cn ersetzen
    ModificationItem replaceCn = new ModificationItem(
        DirContext.REPLACE_ATTRIBUTE, new BasicAttribute("cn",
            "Paulchen Panther"));

    // Aenderungen zu einem Array zusammenfassen
    ModificationItem[] mods = new ModificationItem[] { addTel,
        replaceCn };

    // Eintrag veraenderen via Array
    ctx.modifyAttributes("sn=Panther,ou=personen", mods);

    // eine weitere Veraenderung
    ctx.modifyAttributes("sn=Panther,ou=personen",
        DirContext.ADD_ATTRIBUTE, new BasicAttributes(
            "description", "Der rosarote Panther"));

  }
}
