/* Beispiele aus dem Buch "LDAP fuer Java-Entwickler", 
 * Stefan Zoerner, 4. aktualisierte Auflage 2013
 *  
 * Webseite zum Buch: http://www.ldapjava.de/ 
 * Software & Support Media GmbH / entwickler.press, http://www.entwickler-press.de/
 */
package ldapbuch.kapitel4.ops.search;

import javax.naming.NamingEnumeration;
import javax.naming.NamingException;
import javax.naming.directory.Attribute;
import javax.naming.directory.Attributes;
import javax.naming.directory.DirContext;
import javax.naming.directory.InitialDirContext;
import javax.naming.directory.SearchControls;
import javax.naming.directory.SearchResult;

/**
 * Suchabfrage mit Filter -- (Listing 4_7).
 * 
 * Verbindungsdaten (Host, Base DN) werden von aussen erwartet
 * (jndi.properties).
 * 
 * @author Stefan Z&ouml;rner
 */
public class SucheMitFilter {

  /**
   * Einstiegspunkt.
   * 
   * @param args
   *          Kommandozeilenparameter, es werden keine ben&ouml;tigt
   */
  public static void main(String[] args) throws NamingException {

    DirContext ctx = new InitialDirContext();

    String base = "dc=bundestag,dc=de";
    String filter = "(&(objectclass=person)(sn~=Schmidt)(!(mail=*)))";
    String[] attrNames = { "cn", "title" };

    SearchControls ctls = new SearchControls();
    ctls.setSearchScope(SearchControls.SUBTREE_SCOPE);
    ctls.setReturningAttributes(attrNames);

    NamingEnumeration<SearchResult> enm = ctx.search(base,
        filter, ctls);
    while (enm.hasMore()) {
      SearchResult result = enm.next();
      System.out.println(result.getNameInNamespace());
      Attributes attrs = result.getAttributes();
      NamingEnumeration<? extends Attribute> aEnum = attrs
          .getAll();
      while (aEnum.hasMore()) {
        Attribute attr = aEnum.next();
        System.out.println(attr);
      }
      System.out.println();
    }
  }
}
