/* Beispiele aus dem Buch "LDAP fuer Java-Entwickler", 
 * Stefan Zoerner, 4. aktualisierte Auflage 2013
 *  
 * Webseite zum Buch: http://www.ldapjava.de/ 
 * Software & Support Media GmbH / entwickler.press, http://www.entwickler-press.de/
 */
package ldapbuch.kapitel4.schema;

import javax.naming.NameClassPair;
import javax.naming.NamingEnumeration;
import javax.naming.NamingException;
import javax.naming.directory.DirContext;
import javax.naming.directory.InitialDirContext;

/**
 * Ver&ouml;ffentlichte Bereiche des Schemas -- (Listing 4_24).
 * 
 * Listet die Bereiche des veroeffentlichtes Schemas auf. Je nach Server koennen
 * alle oder einige der folgenden Bestandteile aufgelistet werden:
 * ClassDefinition, AttributeDefinition, MatchingRule, SyntaxDefinition. Jedes
 * stellt einen DirContext dar, das fuer definierte Elemente Bindungen enthaelt.
 * Verbindungsdaten (Host, Base DN) werden von aussen erwartet
 * (jndi.properties).
 * 
 * @author Stefan Z&ouml;rner
 */
public class BereicheAuflisten {

  /**
   * Einstiegspunkt.
   * 
   * @param args
   *          Kommandozeilenargumente (keine)
   */
  public static void main(String[] args) throws NamingException {

    InitialDirContext ctx = new InitialDirContext();
    DirContext schema = ctx.getSchema("");

    NamingEnumeration<NameClassPair> enm = schema.list("");
    while (enm.hasMore()) {
      NameClassPair act = enm.next();
      System.out.println(act.getName() + " -- " + act.getClassName());
    }
  }
}
