/* Beispiele aus dem Buch "LDAP fuer Java-Entwickler", 
 * Stefan Zoerner, 4. aktualisierte Auflage 2013
 *  
 * Webseite zum Buch: http://www.ldapjava.de/ 
 * Software & Support Media GmbH / entwickler.press, http://www.entwickler-press.de/
 */
package ldapbuch.kapitel4.schema;

import javax.naming.NamingException;
import javax.naming.directory.Attribute;
import javax.naming.directory.Attributes;
import javax.naming.directory.DirContext;
import javax.naming.directory.InitialDirContext;

/**
 * Erforderliche Attribute f&uuml;r einen Eintrag anzeigen -- (Listing 4_29).
 * 
 * Listet alle erforderlichen Attribute eines Eintrags einer Objektklasse auf.
 * Dazu wird die Objektklassendefinitionen anhand der Superklassen entlang
 * iteriert, bis keine Oberklasse (Attribut SUP) mehr vorhanden ist (d.h. top
 * ist erreicht). Verbindungsdaten (Host, Base DN) werden von aussen erwartet
 * (jndi.properties).
 * 
 * @author Stefan Z&ouml;rner
 */
public class ErforderlicheAttributeFuerEinenEintragAnzeigen {

  /**
   * Einstiegspunkt.
   * 
   * @param args
   *          Kommandozeilenargumente (keine)
   */
  public static void main(String[] args) throws NamingException {

    InitialDirContext ctx = new InitialDirContext();
    DirContext schema = ctx.getSchema("");
    DirContext allClasses = (DirContext) schema
        .lookup("ClassDefinition");
    String oc = "person";
    do {
      Attributes attrs = allClasses.getAttributes(oc);
      Attribute must = attrs.get("MUST");
      if (must != null) {
        for (int i = 0; i < must.size(); ++i) {
          System.out.println(oc + " erfordert " + must.get(i));
        }
      }
      Attribute sup = attrs.get("SUP");
      oc = (String) ((sup != null) ? sup.get() : null);
    } while (oc != null);
  }
}
