/* Beispiele aus dem Buch "LDAP fuer Java-Entwickler", 
 * Stefan Zoerner, 4. aktualisierte Auflage 2013
 *  
 * Webseite zum Buch: http://www.ldapjava.de/ 
 * Software & Support Media GmbH / entwickler.press, http://www.entwickler-press.de/
 */
package ldapbuch.kapitel4.schema;

import javax.naming.Binding;
import javax.naming.NamingEnumeration;
import javax.naming.NamingException;
import javax.naming.directory.Attributes;
import javax.naming.directory.DirContext;
import javax.naming.directory.InitialDirContext;

/**
 * Objektklassen eines Eintrages anzeigen -- (Listing 4_27).
 * 
 * Listet alle Objektklassen auf, zu denen der Eintrag "ou=personen" unseres
 * Beispielverzeichnisses gehoert. Verbindungsdaten (Host, Base DN) werden von
 * aussen erwartet (jndi.properties).
 * 
 * @author Stefan Z&ouml;rner
 */
public class ObjektklassenEinesEintragsAnzeigen {

  /**
   * Einstiegspunkt.
   * 
   * @param args
   *          Kommandozeilenargumente (keine)
   */
  public static void main(String[] args) throws NamingException {

    InitialDirContext ctx = new InitialDirContext();
    DirContext ocls = ctx.getSchemaClassDefinition("ou=personen");
    NamingEnumeration<Binding> enm = ocls.listBindings("");
    while (enm.hasMore()) {
      Binding bnd = enm.next();
      System.out.print(bnd.getName() + ", ");
      Attributes attrs = ((DirContext) bnd.getObject())
          .getAttributes("");
      System.out.println(attrs.get("DESC").get());
    }
  }
}
