/* Beispiele aus dem Buch "LDAP fuer Java-Entwickler", 
 * Stefan Zoerner, 4. aktualisierte Auflage 2013
 *  
 * Webseite zum Buch: http://www.ldapjava.de/ 
 * Software & Support Media GmbH / entwickler.press, http://www.entwickler-press.de/
 */
package ldapbuch.kapitel4.ssl;

import java.io.IOException;

import javax.naming.Context;
import javax.naming.NamingEnumeration;
import javax.naming.NamingException;
import javax.naming.ldap.InitialLdapContext;
import javax.naming.ldap.LdapContext;
import javax.naming.ldap.StartTlsRequest;
import javax.naming.ldap.StartTlsResponse;
import javax.net.ssl.SSLSession;

/**
 * Ein Beispiel mit StartTLS -- (Listing 4_3).
 * 
 * Verbindungsdaten (Host, Base DN) werden von aussen erwartet
 * (jndi.properties). Zur Ausf&uuml;hrung wird J2SE 1.4 oder h&ouml;her
 * ben&ouml;tigt. Weiterhin muss der Zielserver die Extended Operation "Start
 * TLS" unterst&uuml;tzen.
 * 
 * @author Stefan Z&ouml;rner
 */
public class StartTls {

  /**
   * Einstiegspunkt.
   * 
   * @param args
   *          Kommandozeilenparameter, DN und Kennwort des Benutzers
   */
  public static void main(String[] args) throws NamingException, IOException {

    String user = args[0];
    String pwd = args[1];

    LdapContext ctx = new InitialLdapContext();

    // Ungesicherte Operationen mit anonymer Berechtigung
    // auf ctx durchfuehren
    //
    NamingEnumeration<?> enm = ctx.list("ou=gruppen");
    while (enm.hasMore()) {
      enm.next();
    }
    enm.close();

    // Start TLS ausfuehren
    //
    StartTlsResponse tls = (StartTlsResponse) ctx
        .extendedOperation(new StartTlsRequest());

    SSLSession session = tls.negotiate();
    System.out.println("CipherSuite=" + session.getCipherSuite());

    // Authentifizierung ueber "simple"
    //
    ctx.addToEnvironment(Context.SECURITY_AUTHENTICATION, "simple");
    ctx.addToEnvironment(Context.SECURITY_PRINCIPAL, user);
    ctx.addToEnvironment(Context.SECURITY_CREDENTIALS, pwd);

    // Gesicherte Operationen auf ctx mit der angegebenen Identititt
    // durchfuehren
    // 
    ctx.list("ou=personen,dc=bundestag,dc=de");

    tls.close();
    ctx.close();
  }
}
